heal_post_bundles

Function heal_post_bundles 

pub fn heal_post_bundles(
    runtime_services: Arc<RuntimeServices>,
    sponsor_id: Id,
    bucket_location: BucketLocation,
    peers_visited: &[Peer],
    bundles: Vec<EncodedPostBundleV1>,
)
Selects and returns the best bundle (most posts), then spawns a background task that serially heals every server whose bundle is missing posts that any other server has. Returns None if bundles is empty.